.. _chapter_1_introduction:

Chapter 1: Introduction
=======================

In chapter 1, we introduce you to the **PyAutoFit** and describe how to set up your own model, fit it to data via
a non-linear search and inspect and interpret the results.

You can start the tutorials right now by going to `our binder <https://notebooks.gesis.org/binder/v2/gh/Jammy2211/autofit_workspace/7586a67b726dca612404cf5fab1d77d8738f3737>`_
and navigating to the folder `notebooks/howtofit/chapter_1_introduction`. They are also on the `autofit_workspace <https://github.com/Jammy2211/autofit_workspace>`_.

The chapter contains the following tutorials:

**Tutorial 1: Model Mapping**
- The **PyAutoFit** backend that handles model composition.

**Tutorial 2: Model Fitting**
- Fitting a model with an input set of parameters to data.

**Tutorial 3: Non Linear Search**
- Finding the model parameters that best-fit the data.

**Tutorial 4: Visualization**
- Outputting images during the model-fit and masking your data.

**Tutorial 5: Complex Models**
- Composing and fitting complex models.

**Tutorial 6: Data Extensions**
- Extending the Analysis class with model-specific data strructures and visualization.

**Tutorial 7: Results and Samples**
- The results of a model-fit output by **PyAutoFit**.

**Tutorial 8: Fitting Multiple Datasets**
- Fitting a model to multiple similar datasets.

**Tutorial 9: Aggregator**
- Loading large libraries of results using in-built database tools.

**Tutorial 10: Filtering**
- Filtering the loaded results to find specific results of interest.

**Tutorial 11: Data and Models**
- Replotting the model, data and fits of a set of results.
